//---------------------------------------------------------------------------

// This software is Copyright (c) 2015 Embarcadero Technologies, Inc.
// You may only use this software if you are an authorized licensee
// of an Embarcadero developer tools product.
// This software is considered a Redistributable as defined under
// the software license agreement that comes with the Embarcadero Products
// and is subject to that software license agreement.

//---------------------------------------------------------------------------

unit uActivityIndicator;

interface

uses
  Winapi.Windows,
  Winapi.Messages,
  System.SysUtils,
  System.Variants,
  System.Classes,
  System.ImageList,
  Vcl.Graphics,
  Vcl.Controls,
  Vcl.Forms,
  Vcl.Dialogs,
  Vcl.WinXCtrls,
  Vcl.StdCtrls,
  Vcl.ImgList,
  Vcl.ComCtrls,
  Vcl.ExtCtrls,
  WrapDelphi,WrapDelphiVcl,WrapDelphiForms,PythonEngine;

type
  TActivityIndicatorForm = class(TForm)
    chkAnimate: TCheckBox;
    trkFrameDelay: TTrackBar;
    lblFrameDelay: TLabel;
    grpIndicatorType: TRadioGroup;
    grpIndicatorSize: TRadioGroup;
    grpIndicatorColor: TRadioGroup;
    cbxVclStyles: TComboBox;
    lblVclStyle: TLabel;
    AI: TActivityIndicator;
    cbxFormColor: TColorBox;
    lblFormColor: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure chkAnimateClick(Sender: TObject);
    procedure trkFrameDelayChange(Sender: TObject);
    procedure grpIndicatorTypeClick(Sender: TObject);
    procedure grpIndicatorSizeClick(Sender: TObject);
    procedure grpIndicatorColorClick(Sender: TObject);
    procedure cbxVclStylesChange(Sender: TObject);
    procedure cbxFormColorChange(Sender: TObject);
  private
  public
  end;

  TPyActivityIndicatorForm = class(TPyDelphiForm)
    // Constructors & Destructors
    constructor Create( APythonType : TPythonType ); override;
    constructor CreateWith( PythonType : TPythonType; args : PPyObject ); override;
    // Basic services
    function  Repr : PPyObject; override;
    private
      function  GetDelphiObject: TActivityIndicatorForm;
      procedure SetDelphiObject(const Value: TActivityIndicatorForm);
    protected
      function Get_chkAnimate(AContext: Pointer): PPyObject;
      function Set_chkAnimate(AValue: PPyObject;
  AContext: Pointer): Integer;
    public
      class procedure RegisterGetSets( PythonType : TPythonType ); override;
      class function  DelphiObjectClass : TClass; override;
      property DelphiObject: TActivityIndicatorForm read GetDelphiObject write SetDelphiObject;
  end;
var
  ActivityIndicatorForm: TActivityIndicatorForm;

implementation

{$R *.dfm}

uses
  Vcl.Themes;

procedure TActivityIndicatorForm.FormCreate(Sender: TObject);
var
  StyleName: string;
begin
  for StyleName in TStyleManager.StyleNames do
    cbxVclStyles.Items.Add(StyleName);

  cbxVclStyles.ItemIndex := cbxVclStyles.Items.IndexOf(TStyleManager.ActiveStyle.Name);
end;

procedure TActivityIndicatorForm.cbxFormColorChange(Sender: TObject);
begin
  Color := cbxFormColor.Selected;
end;

procedure TActivityIndicatorForm.cbxVclStylesChange(Sender: TObject);
begin
  TStyleManager.SetStyle(cbxVclStyles.Text);
  lblFormColor.Enabled := StyleServices.IsSystemStyle;
  cbxFormColor.Enabled := StyleServices.IsSystemStyle;
end;

procedure TActivityIndicatorForm.grpIndicatorColorClick(Sender: TObject);
begin
  AI.IndicatorColor := TActivityIndicatorColor(grpIndicatorColor.ItemIndex);
end;

procedure TActivityIndicatorForm.grpIndicatorSizeClick(Sender: TObject);
begin
  AI.IndicatorSize := TActivityIndicatorSize(grpIndicatorSize.ItemIndex);
end;

procedure TActivityIndicatorForm.grpIndicatorTypeClick(Sender: TObject);
begin
  AI.IndicatorType := TActivityIndicatorType(grpIndicatorType.ItemIndex);
end;

procedure TActivityIndicatorForm.trkFrameDelayChange(Sender: TObject);
begin
  AI.FrameDelay := trkFrameDelay.Position * 10;
  lblFrameDelay.Caption := 'Frame Delay (' + IntToStr(AI.FrameDelay) + ')';
end;

procedure TActivityIndicatorForm.chkAnimateClick(Sender: TObject);
begin
  AI.Animate := chkAnimate.Checked;
end;

constructor TPyActivityIndicatorForm.Create( APythonType : TPythonType );
begin
  inherited;
  // we need to set DelphiObject property
  DelphiObject := TActivityIndicatorForm.Create(Application.MainForm);
  with DelphiObject do begin
    chkAnimate.Checked := True;
  end;
  Owned := True; // We own the objects we create
end;

constructor TPyActivityIndicatorForm.CreateWith( PythonType : TPythonType; args : PPyObject );
begin
  inherited;
  with GetPythonEngine, DelphiObject as TActivityIndicatorForm do
    begin
      if PyArg_ParseTuple( args, ':CreateActivityIndicator') <> 0 then
        Exit;
    end;
end;

// Then we override the needed services

class function TPyActivityIndicatorForm.DelphiObjectClass: TClass;
begin
  Result := TActivityIndicatorForm;
end;

function  TPyActivityIndicatorForm.Repr : PPyObject;
begin
  with GetPythonEngine, DelphiObject as TActivityIndicatorForm do
    Result := VariantAsPyObject(Format('(%s)',[Name]));
end;

function TPyActivityIndicatorForm.GetDelphiObject: TActivityIndicatorForm;
begin
  Result := TActivityIndicatorForm(inherited DelphiObject);
end;

procedure TPyActivityIndicatorForm.SetDelphiObject(const Value: TActivityIndicatorForm);
begin
  inherited DelphiObject := Value;
end;
class procedure TPyActivityIndicatorForm.RegisterGetSets(PythonType: TPythonType);
begin
  inherited;
  with PythonType do
    begin
      AddGetSet('Animate', @TPyActivityIndicatorForm.Get_chkAnimate, @TPyActivityIndicatorForm.Set_chkAnimate,
        'Represents the animate value of the checkbox', nil);
    end;
end;
function TPyActivityIndicatorForm.Get_chkAnimate(AContext: Pointer): PPyObject;
begin
  Adjust(@Self);
  Result :=  GetPythonEngine.VariantAsPyObject(DelphiObject.chkAnimate.Checked);
end;

function TPyActivityIndicatorForm.Set_chkAnimate(AValue: PPyObject;
  AContext: Pointer): Integer;
var
  _Animate : Boolean;
begin
  if CheckBoolAttribute(AValue, 'Animate', _Animate) then
    with GetPythonEngine do begin
      Adjust(@Self);
      DelphiObject.chkAnimate.Checked := _Animate;
      Result := 0;
    end
    else
      Result := -1;
end;
end.
